==> modelsummary_0.9.2.tar.gz: modelsummary/tests/testthat/_snaps/huxtable.md <==
# markdown caption and notes

    Code
      cat(unknown)
    Output
      ------------------------------------------------------------
                   OLS 1     Poisson 1 OLS 2     Logit 1  Logit 2 
      ------------ --------- --------- --------- -------- --------
       (Intercept) 349.287** 5.972***  1.349***  17.100   1.403   
                                                                  
                   (103.509) (0.105)   (0.219)   (10.843) (1.368) 
                                                                  
       mpg         -9.417**  -0.078***                            
                                                                  
                   (2.676)   (0.004)                              
                                                                  
       wt          -4.168              -0.072                     
                                                                  
                   (16.485)            (0.087)                    
                                                                  
       drat                  0.139***            -1.717           
                                                                  
                             (0.038)             (1.909)          
                                                                  
       hp                              -0.005*** -0.089*  0.122+  
                                                                  
                                       (0.001)   (0.039)  (0.068) 
                                                                  
       disp                                               -0.095* 
                                                                  
                                                          (0.048) 
                                                                  
       Num.Obs.    32        32        32        32       32      
                                                                  
       R2          0.603               0.534                      
                                                                  
       R2 Adj.     0.576               0.502                      
                                                                  
       AIC         338.8     511.7     29.5      21.9     22.7    
                                                                  
       BIC         344.6     516.1     35.4      26.3     27.1    
                                                                  
       Log.Lik.    -165.392  -252.848  -10.764   -7.928   -8.356  
                                                                  
       F           22.053              16.601                     
                                                                  
       + p < 0.1, * p < 0.05, ** p < 0.01, *** p < 0.001          
                                                                  
       test note                                                  
      ------------------------------------------------------------
      
      Table: test title

==> modelsummary_0.9.3.tar.gz: modelsummary/tests/testthat/_snaps/huxtable.md <==
# markdown caption and notes

    Code
      cat(unknown)
    Output
      ------------------------------------------------------------
                   OLS 1     Poisson 1 OLS 2     Logit 1  Logit 2 
      ------------ --------- --------- --------- -------- --------
       (Intercept) 349.287** 5.972***  1.349***  17.100   1.403   
                                                                  
                   (103.509) (0.105)   (0.219)   (10.843) (1.368) 
                                                                  
       mpg         -9.417**  -0.078***                            
                                                                  
                   (2.676)   (0.004)                              
                                                                  
       wt          -4.168              -0.072                     
                                                                  
                   (16.485)            (0.087)                    
                                                                  
       drat                  0.139***            -1.717           
                                                                  
                             (0.038)             (1.909)          
                                                                  
       hp                              -0.005*** -0.089*  0.122+  
                                                                  
                                       (0.001)   (0.039)  (0.068) 
                                                                  
       disp                                               -0.095* 
                                                                  
                                                          (0.048) 
                                                                  
       Num.Obs.    32        32        32        32       32      
                                                                  
       R2          0.603               0.534                      
                                                                  
       R2 Adj.     0.576               0.502                      
                                                                  
       AIC         338.8     511.7     29.5      21.9     22.7    
                                                                  
       BIC         344.6     516.1     35.4      26.3     27.1    
                                                                  
       Log.Lik.    -165.392  -252.848  -10.764   -7.928   -8.356  
                                                                  
       F           22.053    301.667   16.601    3.013    2.617   
                                                                  
       + p < 0.1, * p < 0.05, ** p < 0.01, *** p < 0.001          
                                                                  
       test note                                                  
      ------------------------------------------------------------
      
      Table: test title
